
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::LicensesController < ApplicationController
  before_action :authenticate_user!, only: [:create, :update, :destroy]
  before_action :set_license, only: [:show, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET /licenses
  # GET /licenses.json
  def index
    render json: License.all, each_serializer: LicenseSerializer
  end

  # GET /licenses/1
  # GET /licenses/1.json
  def show
    render json: @license
  end

  # POST /licenses
  # POST /licenses.json
  def create
    @license = License.new(license_params)
    authorize @license

    if @license.save
      render json: @license, status: :created
    else
      render json: @license.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /licenses/1
  # PATCH/PUT /licenses/1.json
  def update
    if @license.update(license_params)
      head :no_content
    else
      render json: @license.errors, status: :unprocessable_entity
    end
  end

  # DELETE /licenses/1
  # DELETE /licenses/1.json
  def destroy
    @license.destroy

    head :no_content
  end

  private

  def set_license
    @license = License.where(id: params[:id]).first

    render status: :not_found if @license.blank?

    @license
  end

  def license_params
    params.require(:license).permit(:name, :description, :url, :image_url)
  end

  def authorize!
    authorize @license
  end
end
