
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'open-uri'
  class V1::SessionsController < DeviseTokenAuth::SessionsController
    def create
      # Check
      puts(resource_params)
      field = (resource_params.keys.map(&:to_sym) & resource_class.authentication_keys).first

      @resource = nil
      if field
        q_value = get_case_insensitive_field_from_resource_params(field)

        @resource = find_resource(field, q_value)
      end

      if @resource && valid_params?(field, q_value) && (!@resource.respond_to?(:active_for_authentication?) || @resource.active_for_authentication?)
        valid_password = @resource.valid_password?(resource_params[:password])
        if (@resource.respond_to?(:valid_for_authentication?) && !@resource.valid_for_authentication? { valid_password }) || !valid_password
          return render_create_error_bad_credentials
        end
        @token = @resource.create_token
        @resource.save

        sign_in(:user, @resource, store: false, bypass: false)

        yield @resource if block_given?

        render_create_success
      elsif @resource && !(!@resource.respond_to?(:active_for_authentication?) || @resource.active_for_authentication?)
        # verify if user is to be reactivated
        reactivate_user?
        if @resource.blocked?
          render_create_error_blocked
        elsif @resource.banished?
          render_create_error_banished
        end
      else
        render_create_error_bad_credentials
      end

    end

    def render_create_error_not_confirmed
      render json: {
        success: false,
        errors: [ I18n.t("devise.failure.unconfirmed")],
      }, status: 401
       
    end

    def render_create_error_banished
      render json: {
        success: false,
        errors: [ I18n.t("devise.sessions.banished")]
      }, status: 401
    end

    def render_create_error_blocked
      render json: {
        success: false,
        errors: [ I18n.t("devise.sessions.blocked")],
        avaliable_at: @resource.reactivated_at
      }, status: 401
    end
        
    def reactivate_user?
      unless @resource.reactivated_at.nil?
        if @resource.reactivated_at < Time.current
          @resource.active!
          create
        end
      end
    end
  end
