
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: complaints
#
#  id                  :integer          not null, primary key
#  description         :text
#  user_id             :integer
#  complainable_id     :integer
#  complainable_type   :string
#  complaint_reason_id :integer
#  created_at          :datetime         not null
#  updated_at          :datetime         not null
#  state               :integer          default("0")

class Complaint < ApplicationRecord
  # *current_user* create complaint about *complaint_reason* for *complaintable*
  include Trackable

  belongs_to :complaint_reason
  belongs_to :user
  belongs_to :complainable, polymorphic: true

  validates_presence_of :user, :complainable, :description, :complaint_reason
  validates :user_id, uniqueness: { scope: [:complainable_id, :complainable_type] }

  acts_as_paranoid
  has_paper_trail
  
  enum state: { complained: 0, rejected: 1, accepted: 2}

  def reason
    complaint_reason.reason
  end

  def recipient
    complainable
  end
end
