
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: follows
#
#  id              :integer          not null, primary key
#  followable_id   :integer
#  followable_type :string
#  user_id         :integer
#  created_at      :datetime         not null
#  updated_at      :datetime         not null
#

class Follow < ApplicationRecord
  # *current_user* follows *followable*
  include Trackable

  after_create :create_action

  belongs_to :followable, polymorphic: true, counter_cache: true
  belongs_to :user

  validates_presence_of :user, :followable
  validates :user_id, uniqueness: { scope: [:followable_id, :followable_type] }

  def recipient
    followable
  end

  private

  def create_action
    if followable_type == "User"
      user.complete_action(Action.find_by_name("Seguir Usuário"))
      followable.complete_action(Action.find_by_name("Ser Seguido"))
    end
  end
end
