
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: user_categories
#
#  id         :integer          not null, primary key
#  name       :string
#  reference  :float
#  created_at :datetime         not null
#  updated_at :datetime         not null
#

class UserCategory < ApplicationRecord
  has_many :score_user_categories
  has_many :scores, through: :score_user_categories

  validates_presence_of :name
  validates_uniqueness_of :name

  def calculate_reference
    hash = reputation_values

    return 0 unless hash.values.all? { |x| !x.nil? }

    update(reference: ScoreCalculatorService.new(User.new).calculate(hash))

    # defining maximum reference change every reference in UserCategory
    UserCategory.where.not(id: id).find_each(&:calculate_reference) if reference == UserCategory.maximum(:reference)
  end

  private

  # return a hash with 'score code' => 'score_user_category maximum value'
  def reputation_values
    Score.object_type('User').includes(:score_user_categories).map { |s| [s.code, s.score_user_categories.find { |sc| sc.score_id == s.id && sc.user_category_id == id }.value] }.to_h
  end
end
