
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class Dspace::LearningObjectImporter

  def initialize(items, publisher, dspace_client)
    @items = items
    @publisher = publisher
    @dspace_client = dspace_client
  end

  def import
    learning_objects = []
    languages = []
    n_att_los = 0
    @items.each do |item|
      next if item_exists? item
      learning_object = LearningObjectBuilder.build_from_dspace(item, @publisher)
      next if learning_object.blank?
      has_att = create_attachments(learning_object, item.bit_streams)
      if learning_object.link.blank? && !has_att
        links = learning_object.get_metadata_values_of("dc.identifier")
        if !links.blank?
          user_dspace = URI.parse(@publisher.dspace_url)
          link = links[0]
          links.each do |i|
            i.delete!(" \t\r\n")
            begin
              if URI.parse(i).host == user_dspace.host
                link = i
                break
              end
            rescue URI::InvalidURIError
              p "Invalid URI: #{i.to_s}"
            else
              link = i
            end
          end
          learning_object.link = link
          learning_object.attachments.new(retrieve_link: link, bundle_name: "LINK")
        end
      end
      n_att_los += 1 if has_att
      learning_objects << learning_object
      languages << learning_object.language
      yield(learning_object) if block_given?
    end
    p "#{learning_objects.count} items to import"
    p "#{n_att_los} items with attachment"
    if !learning_objects.empty?
      result = LearningObject.import learning_objects, recursive: true
      result.failed_instances.each do |failure|
        p "IMPORT ERRORS:"
        p failure.errors
      end

      learning_objects.each_with_index do |lo, i|
        lo.attachments.each {|i| ThumbnailGenerateWorker.perform_async(i.id)}
        lo.language = languages[i]
        lo.state = LearningObject.states[:published]
        lo.save!
      end
    end
  end

  private

  def create_attachments(learning_object, bitstreams)
    bitstreams = JSON.parse bitstreams if bitstreams.class == String
    has_bitstream = false
    bitstreams.each do |bitstream|
      att = learning_object.attachments.new(::Dspace::AttachmentMapper.call(bitstream))
      if att.bundle_name == "ORE"
        att.retrieve_link = original_link(att)
        has_bitstream = true unless att.retrieve_link.blank?
      else
        has_bitstream = true
      end

    end
    has_bitstream
  end

  def original_link(attachment)
    file = @dspace_client.bitstreams.retrieve(id: attachment.id_dspace).open
    xml = Hash.from_xml(file.read)
    href = xml["entry"]["link"].select {|i| i["href"].include? "bitstream"}
    link = ""
    link = href[0]["href"] unless href.blank?
    File.unlink(file) if File.exist?(file.path)
    link
  end

  def item_exists?(item)
    LearningObject.where(id_dspace: item.id).exists?
  end

  # def get_thumbnail(attachment)
  #   file = @dspace_client.bitstreams.retrieve(id: attachment.id_dspace).open
  #
  #   thumbnail_service = ThumbnailService.new([Thumbnail::Strategies::ImageThumbnailGenerator.new])
  #   thumbnail = thumbnail_service.create_thumbnail(file)
  #   attachment.update(thumbnail: thumbnail)
  # end

  # def update(learning_object_og, new_learning_object)
  #   changes = new_learning_object.dup.delete_if {|k, v| learning_object_og[k] == v}.merge!(learning_object_og.dup.delete_if {|k,v| new_learning_object.has_key?(k)})
  # end

end
