# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class CreateJoinTableLanguageLearningObject < ActiveRecord::Migration[5.0]
  def change
    create_join_table :languages, :learning_objects do |t|
      t.index [:language_id, :learning_object_id],
      :name => 'index_lang_learning_objs_on_language_id_and_learning_object_id'
      # t.index [:learning_object_id, :language_id]
    end

    reversible do |migration|
      start = 1
      finish = 999
      batch_size = 1000
      last_id = LearningObject.count > 0 ? LearningObject.with_deleted.last.id : 0

      migration.up do
        loop do
          begin
            LearningObject.with_deleted.find_each(start: start, finish: finish) do |lo|
              if (lo.language_id)
                lo.update_attributes(language_ids: lo.language_id)
          	  end
            end
          rescue PG::ConnectionBad => e
            logger.warn 'Database error, going to sleep'
            logger.error e
            # Sleeps for a while to wait database's recovery
            sleep(10.seconds)
            # Goes to next iteration to retry
            next
          else
            start += batch_size - 1
            finish += batch_size
            break if start >= last_id
          end
        end
      end

      migration.down do
        loop do
          begin
            LearningObject.with_deleted.find_each(start: start, finish: start) do |lo|
              if (lo.language_id)
                lo.update_attributes(language_id: lo.language_ids.first)
          	  end
            end
          rescue PG::ConnectionBad => e
            logger.warn 'Database error, going to sleep'
            logger.error e
            # Sleeps for a while to wait database's recovery
            sleep(10.seconds)
            # Goes to next iteration to retry
            next
          else
            start += batch_size - 1
            finish += batch_size
            break if start >= last_id
          end
        end
      end
    end

    remove_column :learning_objects, :language_id
  end
end
