# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.


require 'dspace'


namespace :dspace do
  
  desc 'Test id\'s Collection and Community'
  task view_collection: :environment do
    # ============================================================================ #
    # Create Dspace Client
    client = DspaceService.create_client
    if !client.is_running?
      raise 'Can\'t connect to DSpace API.'
    end

    client.communities.all.each do |community|
      puts "-> #{community.name} id = #{community.id}"

      # GET ALL COMMUNITIES's COLLECTIONS
      client.communities.collections(:id => community.id).each do |collection|
        puts "\t->#{collection.name} id= #{collection.id}"

        # GET ALL COLLECTIONS's ITEMS
        client.collections.items(:id => collection.id, limit: 10, offset: 0, expand: "metadata").each do |item|
          puts "\t\t->#{item.name} id = #{item.id}"

          # GET ALL ITEMS's BITSTREAMS
          client.items.bitstreams(:id => item.id).each do |bitstream|
            puts "\t\t\t->#{bitstream.name}"

          end
        end
      end
    end
  end


  desc 'Create DSpace Collection'
  task create_collection: :environment do

    # ============================================================================ #
    # Create Dspace Client
    client = DspaceService.create_client
    if !client.is_running?
      raise 'Can\'t connect to DSpace API.'
    end

    p "------------ Communities"
    p client.communities.all

    # ============================================================================ #
    community = client.communities.create(
      Dspace::Community.new(
        {
          'name' => "Test Community 1",
          'introductoryText' => "This it a test!",
          'shortDescription' => "This is a test!",
          'sidebarText' => "Thist is a test!"
        }
      )
    )
    p "------------ Community created"
    p community
    # ============================================================================ #

    # ============================================================================ #
    # Create COLLECTION
    collection = client.communities.create_collection(
      Dspace::Collection.new(
        {
          'name' => "TEST_COLLECTION",
          'introductoryText' => "This is a test for collection!",
          'shortDescription' => "This is a test for collection!",
          'sidebarText' => "This is a test for collection!"
        }
      ),
      id: community.id
    )
    p "------------ Collection created"
    p collection

    # ============================================================================ #
  end

  desc 'Delete DSpace Collection'
  task delete_collection: :environment do
# ============================================================================ #
    # Create Dspace Client
    client = DspaceService.create_client
    if !client.is_running?
      raise 'Can\'t connect to DSpace API.'
    end
# ============================================================================= #
    community = client.communities.all.last
    # p community
    # collection = client.collections.all.last
    # p collection
   
    # teste = client.collections.delete(id: collection.id)
    # p teste
    client.communities.delete(id: community.id)
  end
end
