
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'rainbow'
require 'logger'

namespace :import do
  desc 'Create educational stage relations based on its metadata'
  task :educational_stage, [:log] => [:environment] do |_t, _args|
    logger = Logger.new(STDOUT)
    educational_relations = {}
    tags = []
    high_stages = ['Educação Superior', 'Ensino Terciário', 'Ensino Superior']

    EducationalStage.all.each do |educational|
      logger.info("Creating relations of #{educational.name}")

      if educational.name == 'Ensino Superior'
        high_stages.select { |stage| tag_exists?(stage) }.each do |stage|
          tags << Tag.find_by_name(stage)
        end
      elsif educational.name == 'Outros'
        tags = Tag.where.not(name: EducationalStage.all.select { |e| e.name != 'Outros' }.map(&:name) + high_stages)
      elsif tag_exists?(educational.name)
        tags << Tag.find_by_name(educational.name)
      end

      tags.each do |tag|
        tag.taggings.each do |tagging|
          next if stage_relation_exists?(educational, tagging.taggable_id, tagging.taggable_type)
          educational_relation = StageRelation.new(educational_stage: educational, stageable_id: tagging.taggable_id, stageable_type: tagging.taggable_type)
          educational_relations[[educational, tagging.taggable_id, tagging.taggable_type]] = educational_relation
        end
      end

      tags = []
    end

    StageRelation.import educational_relations.values
  end

  private

  def tag_exists?(name)
    Tag.where(name: name).exists?
  end

  def stage_relation_exists?(educational, id, type)
    StageRelation.where(educational_stage: educational, stageable_id: id, stageable_type: type).exists?
  end
end
