
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

namespace :score do
  desc 'calculate all objects async'
  task calculate_all: :environment do
    %w(LearningObject Collection User).map { |o| calculate_async(o) }
  end

  desc 'calculate all objects sync'
  task calculate_sync: :environment do
    %w(LearningObject Collection User).each do |klass_name|
      klass = klass_name.constantize
      start = 1
      finish = 1000
      batch_size = 1000
      last_id = klass.count > 0 ? klass.last.id : 0
      loop do
        p "Calculating score for #{klass} ids: #{start} to #{finish}"
        begin
          klass.find_each(start: start, finish: finish) do |object|
            calculator = ScoreCalculatorService.new(object)
            score = calculator.calculate
            object.update_columns(score: score)
            object.update_columns(user_category_id: calculator.category_by_reputation) if klass == "User"
          end
        rescue Exception => e
          p 'Database error, going to sleep'
          p e
          p e.class
          p e.message
          ActiveRecord::Base.clear_active_connections!
          # Sleeps for a while to wait database's recovery
          sleep(60.seconds)
        else
          start += batch_size
          finish += batch_size
          break if start >= last_id
        end
      end
    end
  end

  private

  def calculate_async(object)
    return false unless %w(Collection LearningObject User).include?(object)

    object.constantize.all.find_each do |item|
      ScoreCalculatorWorker.perform_async(item.id, item.class.name)
    end
  end

  def calculate_sync(object)
    calculator = ScoreCalculatorService.new(object)

    score = calculator.calculate

    object.update(score: score) if score.is_a? Float

    object.update(user_category_id: calculator.category_by_reputation) if object.is_a? User
  end
end
