
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'streamio-ffmpeg'

module Thumbnail
  module Strategies
    class VideoThumbnailGenerator < ::Thumbnail::GeneratableStrategy

      def generate(media)
        movie = build_ffmpeg_movie media.path
        hash = SecureRandom.hex(10)
        output = "/tmp/#{hash}.jpg"

        if movie.valid? and !movie.video_codec.nil?
          frame = (movie.duration * 25/100).floor
          movie.screenshot(output,
                           {seek_time: frame, resolution: size},
                           preserve_aspect_ratio: :width)
          File.open output
        else
          raise "ERROR: Video's thumbnail was not generated. (NULL_CODEC)"
        end
      end

      def can_generate?(media)
        super { 'video' }
      end
      private

      def size
        '530x300'
      end

      def build_ffmpeg_movie(path)
        ::FFMPEG::Movie.new(path)
      end

    end
  end
end
