
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Activities' do

  explanation "Users can see the activities of his followed collections and users."

  before { 12.times { create(:learning_object); create(:user) } }

  let(:learning_objects) { LearningObject.all }
  let(:users) { User.all }

  get '/v1/activities' do
    include_context "authenticate_user"

    before do
      create(:like, user: @user)
    end

    example 'Showing all users public activities' do
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/activities/me' do
    include_context "authenticate_user"

    before do
      create(:like, user: @user)
    end

    example 'Showing logged user activities' do
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/users/:id/activities' do
    include_context "authenticate_user"

    let(:id) { users.first.id }

    before do
      create(:follow, followable: users.first, user: @user)
      create(:like, user: users.first)
    end

    example 'Showing activities from a specific user' do
      explanation "This method shows all activities from the logged user."
      do_request
      expect(status).to eq(200)
    end
  end

  get '/v1/feed' do
    include_context "authenticate_user"

    before do
      create(:follow, followable: users.first, user: @user)
      create(:like, user: users.first)
    end

    example 'Showing all activities that logged user can see' do
      do_request
      expect(status).to eq(200)
    end
  end


end
