
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Languages' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Languages are a set of languages which the learning objects can belong to, like portuguese, english and etc."

  let(:languages) { Language.all }

  get '/v1/languages' do
    parameter :limit, 'Limit of languages'
    parameter :offset, 'Offset of languages'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of languages' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Language.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/languages/:id' do
    let(:id) { languages.first.id }

    example 'Get a language' do
      do_request
      expect(path).to eq("/v1/languages/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(Language.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/languages' do
    include_context "authenticate_user_admin"

    parameter :name, 'The name of the language', scope: :language
    parameter :code, 'The code of the language', scope: :language


    let(:name) { Faker::Lorem::word }
    let(:code) { Faker::Address.country_code }
    let(:raw_post) { params.to_json }


    example 'Creating a language' do
      do_request
      expect(status).to eq(201)
    end
  end

  put '/v1/languages/:id' do
    include_context "authenticate_user_admin"

    parameter :id, 'The id of the institution'
    parameter :name, 'The name of the language', scope: :language
    parameter :code, 'The code of the language', scope: :language

    let(:id) { languages.first.id }
    let(:name) { Faker::Lorem::word }
    let(:code) { Faker::Address.country_code }
    let(:raw_post) { params.to_json }

    example 'Updating languages' do
      do_request
      expect(status).to eq(200)
    end
  end

  delete '/v1/languages/:id' do
    include_context "authenticate_user_admin"

    parameter :id, 'The id of the language'

    let(:id) { languages.first.id }

    example 'Destroying a language' do
      do_request
      expect(status).to eq(200)
    end
  end


end
