
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'

resource 'Tags' do

  explanation "Tags to digital resources of free and personal assignment."

  before { 12.times { create(:learning_object) } }

  let(:learning_objects) { LearningObject.all }

  post '/v1/:type/:id/tagging' do
    include_context "authenticate_user"

    parameter :type, 'Represents the type of object, [learning_objects,collections]'
    parameter :id, 'The id of object'

    parameter :name, 'The name of tag', scope: :tags
    parameter :owner_id, 'The id of owner', scope: :tags
    parameter :owner_type, 'Can be [User,Institution]', scope: :tags

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }

    let(:name) { Faker::Lorem.word }
    let(:owner_id) { @user.id }
    let(:owner_type) { "User" }
    let(:raw_post) { params.to_json }

    example_request 'Adding a tag' do
      expect(status).to eq(201)
    end
  end

  delete '/v1/:type/:id/tagging' do
    include_context "authenticate_user"

    parameter :type, 'Represents the type of object, [learning_objects,collections]'
    parameter :id, 'The id of object'

    parameter :name, 'The name of tag', scope: :tags
    parameter :owner_id, 'The id of owner', scope: :tags
    parameter :owner_type, 'Can be [User,Institution]', scope: :tags

    let(:type) { 'learning_objects' }
    let(:id) { learning_objects.first.id }

    let(:name) { "test" }
    let(:owner_id) { @user.id }
    let(:owner_type) { "User" }
    let(:raw_post) { params.to_json }

    before do
      @tag = create(:tag, name: 'test')
      create(:tagging, tagger: @user, taggable: learning_objects.first, tag: @tag)
    end

    example_request ' Untagging a object or collection' do
      expect(status).to eq(200)
    end
  end

end
