
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.require 'acceptance_helpers'

require 'acceptance_helpers'
require 'shared/contexts'

resource 'User Items' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Items owned by an User"

  before { 1.times { create(:user_item) } }

  let(:user_items) { UserItem.all }

  get '/v1/user_items' do   #index
    include_context "authenticate_user"

    before { 12.times { create(:user_item, user: @user) }}

    parameter :limit, 'Limit of user items'
    parameter :offset, 'Offset of user items'
    parameter :item_type, 'Item_type of the user items'
    parameter :op, 'Operation to filter the user items by price [lt, gt, eq]'
    parameter :price, 'Price of the user items'
    parameter :unlock_rule, 'Rule to unlock the user items [achievement, purchase]'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of user items from a user' do
      expect( JSON.parse(response_body).map { |o| o['id'] }.sort ).to eq(@user.items.active.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/user_items/:id' do
      
    let(:id) { user_items.first.id }      

    example 'Get a specific user item' do
      do_request
      expect(path).to eq("/v1/user_items/#{id}")
      expect(response_body).to eq(Helper.serialize(UserItem.find(id)))
      expect(status).to eq(200)
    end
  end
end